/*
 *  Terminal IIIMCF Interface 0.6.1.8
 *  nskystars at yahoo.com
 *
 *  The Terminal IIIMCF Interface (tii) provides functions that
 *  allow programmers a simplified access to the input method
 *  functions of IIIMCF.
 *  The tii package comes with Terminal IIIMCF Input Method (tiim),
 *  a program based on termim which allows console/terminal users
 *  to use multiple languages through TII/IIIMCF.
 *  (tiim is currenly under development)
 */

#define DEBUG 0

int wchar_to_utf8(wchar_t c, char * outbuf, int bufsize);
char * card16_to_utf8(const IIIMP_card16 * pu16);
char * iiimcf_text_to_utf8(IIIMCF_text t);

void tii_register_error_handler(void (*handler_func)(char *, int));
void tii_register_message_handler(void (*handler_func)(char *, char *));
void tii_register_lookup_handler(void (*handler_func)(char *, int, int, int, int, int, int, char **, char **));
void tii_register_preedit_handler(void (*handler_func)(char *, int));
void tii_register_commit_handler(void (*handler_func)(char *));
void tii_register_status_handler(void (*handler_func)(char *));
void tii_register_keyevent_handler(void (*handler_func)(int, char, int));

int tii_fwd_trigger(IIIMCF_context cx, int flag);
int tii_fwd_key(IIIMCF_context cx, int keycode, int keychar, int mod);

int tii_process_events(IIIMCF_context cx);

char ** tii_get_im_list(IIIMCF_handle hx);
char ** tii_get_lang_list(IIIMCF_input_method im);
IIIMCF_input_method tii_find_im(IIIMCF_handle hx, char * im_str);
IIIMCF_language tii_find_lang(IIIMCF_handle hx, char * im_str, char * lang_str);

void tii_free_list(char ** im_lang_arr);

int tii_get_conversion_mode(IIIMCF_context cx);

int tii_init_iiimcf(void);
void tii_finalize_iiimcf(void);

IIIMCF_handle tii_create_handle(void);
void tii_destroy_handle(IIIMCF_handle hx);

IIIMCF_context tii_create_context(IIIMCF_handle hx, IIIMCF_input_method im, IIIMCF_language lang, int trigger_auto);
void tii_destroy_context(IIIMCF_context cx);
